
#include <iostream>

#include "TSystem.h"
#include "TStyle.h"
#include "TROOT.h"
#include "TH1.h"
#include "TCanvas.h"

#include "TArtEventStore.h"
#include "TArtRawEventObject.h"

#include "TArtDataNEBULA.hh"
#include "TArtParameterNEBULA.hh"
#include "TArtLoadMethod.hh"
#include "TArtAnalysisMethod.hh"
#include "TArtAnalysisManager.hh"

void test_compile()
{
  TArtDataNEBULA *datanebula = new TArtDataNEBULA;
  TArtParameterNEBULA *parameternebula = new TArtParameterNEBULA("db/NEBULA.xml");

  TArtLoadMethod *lm = new TArtLoadMethod(datanebula, parameternebula);
  TArtAnalysisMethod *im = new TArtAnalysisMethod(datanebula);

  TArtAnalysisManager am;
  am.AddLoadMethod(lm);
  am.AddAnalysisMethod(im);

  TArtEventStore *estore = new TArtEventStore();
  TArtRawEventObject *rawevent = new TArtRawEventObject();
  estore->Initialize(rawevent); 
  estore->Open("ridf/test.ridf");

  TH1* hadc = new TH1I("hadc", "hist of adc", 4100, 0, 4100);
  TH1* htdc = new TH1I("htdc", "hist of tdc", 4100, 0, 4100);

  int neve = 0;
  while(estore->GetNextEvent() && neve<10000){
    std::cout << "AnaNEBULA: " << ++neve << std::endl;

    am.DoAll(rawevent);

    TArtDataNEBULA::TArtDataNEBULAInnerMap::iterator it = datanebula->InnerMapBegin();
    while(it !=  datanebula->InnerMapEnd()){
      hadc->Fill(it->second.fADC);
      htdc->Fill(it->second.fTDC);
      ++it;
    }

    rawevent->Clear();
  }

  TCanvas* canvas = TCanvas::MakeDefCanvas();
  canvas->Divide(1,2);
  canvas->cd(1);
  hadc->Draw();
  canvas->cd(2);
  htdc->Draw();
}
