#ifndef _TARTDALI_H_
#define _TARTDALI_H_

#include <TClonesArray.h>
#include "TArtCalibDALI.h"

class TArtDALIParameters;
class TArtDALIPara;
class TArtTOF;

class TArtDALIArray : public TClonesArray {

 public:
  TArtDALIArray();
  virtual ~TArtDALIArray(){}
  virtual TArtDALI * FindNaI(Int_t id);
  virtual void ReconstructData();
  virtual void DopplerCorrect(TArtTOF *tof);

  ClassDef(TArtDALIArray,1);

};

class TArtDALI: public TNamed {

 public:
  TArtDALI(TArtDALIPara *p);
  virtual ~TArtDALI();

  void   ReconstructData();
  Bool_t IsReconstructed(){ return fReconstructed; }

  void   DopplerCorrect(TArtTOF *tof);

  // calibration parameter
  Int_t  GetID();
  Int_t  GetFpl();
  TString * GetDetectorName();

  // function to set raw data
  void  SetChannel(int val){channel = val;}
  void  SetRawADC(int val){fADC = val;}
  void  SetRawTDC(int val){fTDC = val;}

  // function to get raw data
  int  GetChannel(){return channel;}
  unsigned int GetRawADC(){return fADC;}
  unsigned int GetRawTDC(){return fTDC;}

  // function to set reco data
  void  SetEnergy(int val){fEnergy = val;}
  void  SetTime(int val){fTime = val;}

  // function to get reco data
  Double_t GetEnergy(){return fEnergy;}
  Double_t GetDoppCorEnergy(){return fDoppCorEnergy;}
  Double_t GetTime(){return fTime;}

 private:
  unsigned int fADC;  
  unsigned int fTDC;  

  int channel;  
  Double_t fEnergy;  
  Double_t fDoppCorEnergy;  
  Double_t fTime;  

  bool fReconstructed;
  TArtDALIPara *para;

  ClassDef(TArtDALI,1);

};
#endif

