#include "TArtDALI.h" 
#include "TArtDALIPara.h" 
#include "TArtCore.h" 
#include "TArtDALIParameters.h"
#include "TArtTOF.h"

#include <TRandom.h>
#include <TMath.h>

//__________________________________________________________
TArtDALIArray::TArtDALIArray() :
  TClonesArray("TArtDALI",100)
{
}

//__________________________________________________________
TArtDALI * TArtDALIArray::FindNaI(Int_t id) 
{
  for(int i=0;i<GetEntries();i++)
    if(  id == ((TArtDALI*)At(i))->GetID() )
      return (TArtDALI*)At(i);

  return NULL;
}

//__________________________________________________________
void TArtDALIArray::ReconstructData() 
{
  for(int i=0;i<GetEntries();i++)
    ((TArtDALI*)At(i))->ReconstructData();
}

//__________________________________________________________
void TArtDALIArray::DopplerCorrect(TArtTOF *tof){
  for(int i=0;i<GetEntries();i++)
    ((TArtDALI*)At(i))->DopplerCorrect((TArtTOF*)tof);
}


//__________________________________________________________
TArtDALI::TArtDALI(TArtDALIPara *p)
  :fReconstructed(false), para(p)
{
}

//__________________________________________________________
TArtDALI::~TArtDALI()  {
}

//__________________________________________________________
void TArtDALI::ReconstructData()  {

  static TRandom *r = new TRandom();
  if(fTDC>0 && fADC>0 && fTDC<100000 && fADC<100000){
  }
  else{ return; }

  float random = r->Rndm();
  fTime = (fTDC + random) * para->GetTCal();
  random = r->Rndm();
  fEnergy = (fADC + random - para->GetQPed()) * para->GetQCal();
  
  fReconstructed = true;

}

//__________________________________________________________
void TArtDALI::DopplerCorrect(TArtTOF *tof){

  if(!fReconstructed){
    TArtCore::Info(__FILE__,"Data is not reconstructed.");
    return;
  }

  // reconstructed position and angle based on PPAC information is too fine and not used since the most of the resolution is determined by DALI-NaI angle resolution.

  Double_t fBeta = tof->GetBeta();
  fDoppCorEnergy = fEnergy * (1-fBeta*TMath::Cos(para->GetNaITheta()))/TMath::Sqrt((1.0-fBeta*fBeta));

}

//__________________________________________________________
Int_t TArtDALI::GetID() {
  return para->GetID();
}
//__________________________________________________________
TString * TArtDALI::GetDetectorName() {
  return (TString *)para->GetDetectorName();
}
//__________________________________________________________
Int_t TArtDALI::GetFpl() {
  return para->GetFpl();
}

